==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/xtchgnumHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "replacement of numerical value by the specified condition"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-f*/
#define FLDT "field list"
#define FLDC "a list of numerical attributes you want to replace"
#define FLDF NULL

/*-R*/
#define LSTT "a list of numerical intervals"
#define LSTC "Specify the numerical intervals targeted for replacement (1.1_2.5 : at least 1.1 and less than 2.5)"

/*-v*/
#define VALT "a list of character strings"
#define VALC "Specify character strings which replaces the numerical intervals specified by -R"

/*-O*/
#define OTHT "character string standing for vaules not satisfied by -c"
#define OTHC "Specify  character string which replaces  the value which does not satisfy the condition by -c. If -O is used, that value is replaced by null value.1"

/*-F*/
#define FRPT "No replacement is done for values which does not satisfy the condition by  -c"
#define FRPC "This flag leaves the attribute value as the original one, if the replacement  condition is not satisfied"

/*-r*/
#define REQT "change the way of specifying the interval"
#define REQC "With this option, '1.1_2.5' is treated as the interval 
whose value is larger than 1.1 and less than or equal to 2.5'."

/*-A*/
#define NEWT C_NEWT
#define NEWC C_NEWC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "
This command replaces the numerical attributes specified with -f  by character strings  which are given by replacement condition with -c."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtchgnum -f amount -R MIN,5,10,MAX -v Max,medium,Min -i dat.xt -o rsl.xt\n\
xtchgnum -f amount -R 0,5,10,20 -v Max,medium,Min -O other amount -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtchgstr,xtsed"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre4.tar.gz: musashi-core-1.0.4-pre4/help/en/xtchgnumHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "replacement of numerical value by the specified condition"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-f*/
#define FLDT "attribute list"
#define FLDC "a list of numerical attributes you want to replace"
#define FLDF NULL

/*-R*/
#define LSTT "a list of numerical intervals"
#define LSTC "Specify the numerical intervals targeted for replacement (1.1_2.5 : at least 1.1 and less than 2.5)"

/*-v*/
#define VALT "a list of character strings"
#define VALC "Specify character strings which replaces the numerical intervals specified by -R"

/*-O*/
#define OTHT "character string standing for vaules not satisfied by -c"
#define OTHC "Specify  character string which replaces  the value which does not satisfy the condition by -c. If -O is used, that value is replaced by null value.1"

/*-F*/
#define FRPT "No replacement is done for values which does not satisfy the condition by  -c"
#define FRPC "This flag leaves the attribute value as the original one, if the replacement  condition is not satisfied"

/*-r*/
#define REQT "change the way of specifying the interval"
#define REQC "With this option, '1.1_2.5' is treated as the interval whose value is larger than 1.1 and less than or equal to 2.5'."

/*-A*/
#define NEWT C_NEWT
#define NEWC C_NEWC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "xtchgnum replaces the numerical value in the attribute specified by -f with character strings corresponding to the numerical range. Instead of replacing strings in place, the newly defined character string can be stored as a new attribute when the option -A is specified. Multiple replacement conditions for numerical values can be defined in ranges at option -R, followed by replacement character strings for numerical values that falls in between each range. If the value does not fall into any of the intervals, it will be replaced by a null character *. You may replace null values by other characters with the option -O. Alternatively, the option -F allows the numerial value to be left unchanged if the condition is not satisfied. Option -O and -F cannot be used at the same time. "

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtchgnum -f amount -R MIN,5,10,MAX -v Max,medium,Min -i dat.xt -o rsl.xt\n\
xtchgnum -f amount -R 0,5,10,20 -v Max,medium,Min -O other amount -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtchgstr,xtsed"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
